@@ -14,9 +14,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import Dict, Optional, Sequence, Tuple, Union
+from typing import Sequence
 
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud import datacatalog
 from google.cloud.datacatalog import (
@@ -41,9 +43,6 @@ class CloudDataCatalogHook(GoogleBaseHook):
     Hook for Google Cloud Data Catalog Service.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -57,20 +56,24 @@ class CloudDataCatalogHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client: Optional[DataCatalogClient] = None
+        self._client: DataCatalogClient | None = None
 
     def get_conn(self) -> DataCatalogClient:
         """Retrieves client library object that allow access to Cloud Data Catalog service."""
         if not self._client:
-            self._client = DataCatalogClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._client = DataCatalogClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -79,11 +82,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         entry_group: str,
         entry_id: str,
-        entry: Union[dict, Entry],
+        entry: dict | Entry,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         """
         Creates an entry.
@@ -106,14 +109,14 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}"
-        self.log.info('Creating a new entry: parent=%s', parent)
+        self.log.info("Creating a new entry: parent=%s", parent)
         result = client.create_entry(
-            request={'parent': parent, 'entry_id': entry_id, 'entry': entry},
+            request={"parent": parent, "entry_id": entry_id, "entry": entry},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Created a entry: name=%s', result.name)
+        self.log.info("Created a entry: name=%s", result.name)
         return result
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -121,11 +124,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         self,
         location: str,
         entry_group_id: str,
-        entry_group: Union[Dict, EntryGroup],
+        entry_group: dict | EntryGroup,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> EntryGroup:
         """
         Creates an EntryGroup.
@@ -148,15 +151,15 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
-        self.log.info('Creating a new entry group: parent=%s', parent)
+        self.log.info("Creating a new entry group: parent=%s", parent)
 
         result = client.create_entry_group(
-            request={'parent': parent, 'entry_group_id': entry_group_id, 'entry_group': entry_group},
+            request={"parent": parent, "entry_group_id": entry_group_id, "entry_group": entry_group},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Created a entry group: name=%s', result.name)
+        self.log.info("Created a entry group: name=%s", result.name)
 
         return result
 
@@ -166,12 +169,12 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         entry_group: str,
         entry: str,
-        tag: Union[dict, Tag],
+        tag: dict | Tag,
         project_id: str = PROVIDE_PROJECT_ID,
-        template_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        template_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Tag:
         """
         Creates a tag on an entry.
@@ -200,16 +203,16 @@ class CloudDataCatalogHook(GoogleBaseHook):
                 tag["template"] = template_path
         parent = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
 
-        self.log.info('Creating a new tag: parent=%s', parent)
+        self.log.info("Creating a new tag: parent=%s", parent)
         # HACK: google-cloud-datacatalog has problems with mapping messages where the value is not a
         # primitive type, so we need to convert it manually.
         # See: https://github.com/googleapis/python-datacatalog/issues/84
         if isinstance(tag, dict):
             tag = Tag(
-                name=tag.get('name'),
-                template=tag.get('template'),
-                template_display_name=tag.get('template_display_name'),
-                column=tag.get('column'),
+                name=tag.get("name"),
+                template=tag.get("template"),
+                template_display_name=tag.get("template_display_name"),
+                column=tag.get("column"),
                 fields={
                     k: datacatalog.TagField(**v) if isinstance(v, dict) else v
                     for k, v in tag.get("fields", {}).items()
@@ -221,7 +224,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         )
 
         result = client.create_tag(request=request, retry=retry, timeout=timeout, metadata=metadata or ())
-        self.log.info('Created a tag: name=%s', result.name)
+        self.log.info("Created a tag: name=%s", result.name)
 
         return result
 
@@ -230,11 +233,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         self,
         location,
         tag_template_id: str,
-        tag_template: Union[dict, TagTemplate],
+        tag_template: dict | TagTemplate,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplate:
         """
         Creates a tag template.
@@ -256,7 +259,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
 
-        self.log.info('Creating a new tag template: parent=%s', parent)
+        self.log.info("Creating a new tag template: parent=%s", parent)
         # HACK: google-cloud-datacatalog has problems with mapping messages where the value is not a
         # primitive type, so we need to convert it manually.
         # See: https://github.com/googleapis/python-datacatalog/issues/84
@@ -279,7 +282,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Created a tag template: name=%s', result.name)
+        self.log.info("Created a tag template: name=%s", result.name)
 
         return result
 
@@ -289,11 +292,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         tag_template: str,
         tag_template_field_id: str,
-        tag_template_field: Union[dict, TagTemplateField],
+        tag_template_field: dict | TagTemplateField,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplateField:
         r"""
         Creates a field in a tag template.
@@ -319,20 +322,20 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
 
-        self.log.info('Creating a new tag template field: parent=%s', parent)
+        self.log.info("Creating a new tag template field: parent=%s", parent)
 
         result = client.create_tag_template_field(
             request={
-                'parent': parent,
-                'tag_template_field_id': tag_template_field_id,
-                'tag_template_field': tag_template_field,
+                "parent": parent,
+                "tag_template_field_id": tag_template_field_id,
+                "tag_template_field": tag_template_field,
             },
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('Created a tag template field: name=%s', result.name)
+        self.log.info("Created a tag template field: name=%s", result.name)
 
         return result
 
@@ -343,9 +346,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         entry_group: str,
         entry: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes an existing entry.
@@ -363,9 +366,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         """
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
-        self.log.info('Deleting a entry: name=%s', name)
-        client.delete_entry(request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ())
-        self.log.info('Deleted a entry: name=%s', name)
+        self.log.info("Deleting a entry: name=%s", name)
+        client.delete_entry(request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ())
+        self.log.info("Deleted a entry: name=%s", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_entry_group(
@@ -373,9 +376,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location,
         entry_group,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes an EntryGroup.
@@ -395,11 +398,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}"
 
-        self.log.info('Deleting a entry group: name=%s', name)
+        self.log.info("Deleting a entry group: name=%s", name)
         client.delete_entry_group(
-            request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+            request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
-        self.log.info('Deleted a entry group: name=%s', name)
+        self.log.info("Deleted a entry group: name=%s", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_tag(
@@ -409,9 +412,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         entry: str,
         tag: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a tag.
@@ -433,9 +436,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
             f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}/tags/{tag}"
         )
 
-        self.log.info('Deleting a tag: name=%s', name)
-        client.delete_tag(request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ())
-        self.log.info('Deleted a tag: name=%s', name)
+        self.log.info("Deleting a tag: name=%s", name)
+        client.delete_tag(request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ())
+        self.log.info("Deleted a tag: name=%s", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_tag_template(
@@ -444,9 +447,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         tag_template,
         force: bool,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a tag template and all tags using the template.
@@ -467,11 +470,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
 
-        self.log.info('Deleting a tag template: name=%s', name)
+        self.log.info("Deleting a tag template: name=%s", name)
         client.delete_tag_template(
-            request={'name': name, 'force': force}, retry=retry, timeout=timeout, metadata=metadata or ()
+            request={"name": name, "force": force}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
-        self.log.info('Deleted a tag template: name=%s', name)
+        self.log.info("Deleted a tag template: name=%s", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_tag_template_field(
@@ -481,9 +484,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         field: str,
         force: bool,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a field in a tag template and all uses of that field.
@@ -503,11 +506,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}/fields/{field}"
 
-        self.log.info('Deleting a tag template field: name=%s', name)
+        self.log.info("Deleting a tag template field: name=%s", name)
         client.delete_tag_template_field(
-            request={'name': name, 'force': force}, retry=retry, timeout=timeout, metadata=metadata or ()
+            request={"name": name, "force": force}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
-        self.log.info('Deleted a tag template field: name=%s', name)
+        self.log.info("Deleted a tag template field: name=%s", name)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def get_entry(
@@ -516,9 +519,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         entry_group: str,
         entry: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         """
         Gets an entry.
@@ -537,11 +540,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
 
-        self.log.info('Getting a entry: name=%s', name)
+        self.log.info("Getting a entry: name=%s", name)
         result = client.get_entry(
-            request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+            request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
-        self.log.info('Received a entry: name=%s', result.name)
+        self.log.info("Received a entry: name=%s", result.name)
 
         return result
 
@@ -551,10 +554,10 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         entry_group: str,
         project_id: str,
-        read_mask: Optional[FieldMask] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        read_mask: FieldMask | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> EntryGroup:
         """
         Gets an entry group.
@@ -576,16 +579,16 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}"
 
-        self.log.info('Getting a entry group: name=%s', name)
+        self.log.info("Getting a entry group: name=%s", name)
 
         result = client.get_entry_group(
-            request={'name': name, 'read_mask': read_mask},
+            request={"name": name, "read_mask": read_mask},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('Received a entry group: name=%s', result.name)
+        self.log.info("Received a entry group: name=%s", result.name)
 
         return result
 
@@ -595,9 +598,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         location: str,
         tag_template: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplate:
         """
         Gets a tag template.
@@ -615,13 +618,13 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}"
 
-        self.log.info('Getting a tag template: name=%s', name)
+        self.log.info("Getting a tag template: name=%s", name)
 
         result = client.get_tag_template(
-            request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+            request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ()
         )
 
-        self.log.info('Received a tag template: name=%s', result.name)
+        self.log.info("Received a tag template: name=%s", result.name)
 
         return result
 
@@ -633,9 +636,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         entry: str,
         project_id: str,
         page_size: int = 100,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Lists the tags on an Entry.
@@ -657,16 +660,16 @@ class CloudDataCatalogHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}/entryGroups/{entry_group}/entries/{entry}"
 
-        self.log.info('Listing tag on entry: entry_name=%s', parent)
+        self.log.info("Listing tag on entry: entry_name=%s", parent)
 
         result = client.list_tags(
-            request={'parent': parent, 'page_size': page_size},
+            request={"parent": parent, "page_size": page_size},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('Received tags.')
+        self.log.info("Received tags.")
 
         return result
 
@@ -678,9 +681,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         entry: str,
         template_name: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Tag:
         """
         Gets for a tag with a specific template for a specific entry.
@@ -711,11 +714,11 @@ class CloudDataCatalogHook(GoogleBaseHook):
 
     def lookup_entry(
         self,
-        linked_resource: Optional[str] = None,
-        sql_resource: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        linked_resource: str | None = None,
+        sql_resource: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         r"""
         Get an entry by target resource name.
@@ -742,22 +745,22 @@ class CloudDataCatalogHook(GoogleBaseHook):
             raise AirflowException("At least one of linked_resource, sql_resource should be set.")
 
         if linked_resource:
-            self.log.info('Getting entry: linked_resource=%s', linked_resource)
+            self.log.info("Getting entry: linked_resource=%s", linked_resource)
             result = client.lookup_entry(
-                request={'linked_resource': linked_resource},
+                request={"linked_resource": linked_resource},
                 retry=retry,
                 timeout=timeout,
                 metadata=metadata,
             )
         else:
-            self.log.info('Getting entry: sql_resource=%s', sql_resource)
+            self.log.info("Getting entry: sql_resource=%s", sql_resource)
             result = client.lookup_entry(
-                request={'sql_resource': sql_resource},
+                request={"sql_resource": sql_resource},
                 retry=retry,
                 timeout=timeout,
                 metadata=metadata,
             )
-        self.log.info('Received entry. name=%s', result.name)
+        self.log.info("Received entry. name=%s", result.name)
 
         return result
 
@@ -769,9 +772,9 @@ class CloudDataCatalogHook(GoogleBaseHook):
         field: str,
         new_tag_template_field_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplateField:
         """
         Renames a field in a tag template.
@@ -794,29 +797,29 @@ class CloudDataCatalogHook(GoogleBaseHook):
         name = f"projects/{project_id}/locations/{location}/tagTemplates/{tag_template}/fields/{field}"
 
         self.log.info(
-            'Renaming field: old_name=%s, new_tag_template_field_id=%s', name, new_tag_template_field_id
+            "Renaming field: old_name=%s, new_tag_template_field_id=%s", name, new_tag_template_field_id
         )
 
         result = client.rename_tag_template_field(
-            request={'name': name, 'new_tag_template_field_id': new_tag_template_field_id},
+            request={"name": name, "new_tag_template_field_id": new_tag_template_field_id},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('Renamed tag template field.')
+        self.log.info("Renamed tag template field.")
 
         return result
 
     def search_catalog(
         self,
-        scope: Union[Dict, SearchCatalogRequest.Scope],
+        scope: dict | SearchCatalogRequest.Scope,
         query: str,
         page_size: int = 100,
-        order_by: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        order_by: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         r"""
         Searches Data Catalog for multiple resources like entries, tags that match a query.
@@ -869,28 +872,28 @@ class CloudDataCatalogHook(GoogleBaseHook):
             order_by,
         )
         result = client.search_catalog(
-            request={'scope': scope, 'query': query, 'page_size': page_size, 'order_by': order_by},
+            request={"scope": scope, "query": query, "page_size": page_size, "order_by": order_by},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('Received items.')
+        self.log.info("Received items.")
 
         return result
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_entry(
         self,
-        entry: Union[Dict, Entry],
-        update_mask: Union[dict, FieldMask],
+        entry: dict | Entry,
+        update_mask: dict | FieldMask,
         project_id: str,
-        location: Optional[str] = None,
-        entry_group: Optional[str] = None,
-        entry_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        entry_group: str | None = None,
+        entry_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         """
         Updates an existing entry.
@@ -938,29 +941,29 @@ class CloudDataCatalogHook(GoogleBaseHook):
         if isinstance(entry, dict):
             entry = Entry(**entry)
         result = client.update_entry(
-            request={'entry': entry, 'update_mask': update_mask},
+            request={"entry": entry, "update_mask": update_mask},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
 
-        self.log.info('Updated entry.')
+        self.log.info("Updated entry.")
 
         return result
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_tag(
         self,
-        tag: Union[Dict, Tag],
-        update_mask: Union[Dict, FieldMask],
+        tag: dict | Tag,
+        update_mask: dict | FieldMask,
         project_id: str,
-        location: Optional[str] = None,
-        entry_group: Optional[str] = None,
-        entry: Optional[str] = None,
-        tag_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        entry_group: str | None = None,
+        entry: str | None = None,
+        tag_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> Tag:
         """
         Updates an existing tag.
@@ -1011,26 +1014,26 @@ class CloudDataCatalogHook(GoogleBaseHook):
         if isinstance(tag, dict):
             tag = Tag(**tag)
         result = client.update_tag(
-            request={'tag': tag, 'update_mask': update_mask},
+            request={"tag": tag, "update_mask": update_mask},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Updated tag.')
+        self.log.info("Updated tag.")
 
         return result
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_tag_template(
         self,
-        tag_template: Union[dict, TagTemplate],
-        update_mask: Union[dict, FieldMask],
+        tag_template: dict | TagTemplate,
+        update_mask: dict | FieldMask,
         project_id: str,
-        location: Optional[str] = None,
-        tag_template_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        tag_template_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplate:
         """
         Updates a tag template.
@@ -1083,28 +1086,28 @@ class CloudDataCatalogHook(GoogleBaseHook):
         if isinstance(tag_template, dict):
             tag_template = TagTemplate(**tag_template)
         result = client.update_tag_template(
-            request={'tag_template': tag_template, 'update_mask': update_mask},
+            request={"tag_template": tag_template, "update_mask": update_mask},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Updated tag template.')
+        self.log.info("Updated tag template.")
 
         return result
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_tag_template_field(
         self,
-        tag_template_field: Union[dict, TagTemplateField],
-        update_mask: Union[dict, FieldMask],
+        tag_template_field: dict | TagTemplateField,
+        update_mask: dict | FieldMask,
         project_id: str,
-        tag_template_field_name: Optional[str] = None,
-        location: Optional[str] = None,
-        tag_template: Optional[str] = None,
-        tag_template_field_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        tag_template_field_name: str | None = None,
+        location: str | None = None,
+        tag_template: str | None = None,
+        tag_template_field_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Updates a field in a tag template. This method cannot be used to update the field type.
@@ -1148,14 +1151,14 @@ class CloudDataCatalogHook(GoogleBaseHook):
 
         result = client.update_tag_template_field(
             request={
-                'name': tag_template_field_name,
-                'tag_template_field': tag_template_field,
-                'update_mask': update_mask,
+                "name": tag_template_field_name,
+                "tag_template_field": tag_template_field,
+                "update_mask": update_mask,
             },
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
-        self.log.info('Updated tag template field.')
+        self.log.info("Updated tag template field.")
 
         return result
