@@ -268,10 +268,7 @@ class CreateBatchPredictionJobOperator(GoogleCloudBaseOperator):
         return batch_prediction_job
 
     def on_kill(self) -> None:
-        """
-        Callback called when the operator is killed.
-        Cancel any running job.
-        """
+        """Callback called when the operator is killed; cancel any running job."""
         if self.hook:
             self.hook.cancel_batch_prediction_job()
 
