@@ -49,9 +49,10 @@ except ModuleNotFoundError:
 
 class WorkflowsCreateWorkflowOperator(GoogleCloudBaseOperator):
     """
-    Creates a new workflow. If a workflow with the specified name
-    already exists in the specified project and location, the long
-    running operation will return
+    Creates a new workflow.
+
+    If a workflow with the specified name already exists in the specified
+    project and location, the long running operation will return
     [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
     .. seealso::
@@ -159,6 +160,7 @@ class WorkflowsCreateWorkflowOperator(GoogleCloudBaseOperator):
 class WorkflowsUpdateWorkflowOperator(GoogleCloudBaseOperator):
     """
     Updates an existing workflow.
+
     Running this method has no impact on already running
     executions of the workflow. A new revision of the
     workflow may be created as a result of a successful
@@ -245,9 +247,7 @@ class WorkflowsUpdateWorkflowOperator(GoogleCloudBaseOperator):
 
 class WorkflowsDeleteWorkflowOperator(GoogleCloudBaseOperator):
     """
-    Deletes a workflow with the specified name.
-    This method also cancels and deletes all running
-    executions of the workflow.
+    Delete a workflow with the specified name and all running executions of the workflow.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -305,8 +305,7 @@ class WorkflowsDeleteWorkflowOperator(GoogleCloudBaseOperator):
 
 class WorkflowsListWorkflowsOperator(GoogleCloudBaseOperator):
     """
-    Lists Workflows in a given project and location.
-    The default order is not specified.
+    Lists Workflows in a given project and location; the default order is not specified.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -447,8 +446,7 @@ class WorkflowsGetWorkflowOperator(GoogleCloudBaseOperator):
 
 class WorkflowsCreateExecutionOperator(GoogleCloudBaseOperator):
     """
-    Creates a new execution using the latest revision of
-    the given workflow.
+    Creates a new execution using the latest revision of the given workflow.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -597,11 +595,10 @@ class WorkflowsCancelExecutionOperator(GoogleCloudBaseOperator):
 
 class WorkflowsListExecutionsOperator(GoogleCloudBaseOperator):
     """
-    Returns a list of executions which belong to the
-    workflow with the given name. The method returns
-    executions of all workflow revisions. Returned
-    executions are ordered by their start time (newest
-    first).
+    Returns a list of executions which belong to the workflow with the given name.
+
+    The method returns executions of all workflow revisions. Returned
+    executions are ordered by their start time (newest first).
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
